package com.flyer.foster.controller;

import cn.dev33.satoken.annotation.SaCheckLogin;
import com.flyer.foster.dto.AreaAddDTO;
import com.flyer.foster.dto.PosterLibUpdateDTO;
import com.flyer.foster.dto.TreeAddDTO;
import com.flyer.foster.dto.TreeUpdateDTO;
import com.flyer.foster.entity.PosterLib;
import com.flyer.foster.entity.Tree;
import com.flyer.foster.service.IAreaService;
import com.flyer.foster.service.ITreeService;
import com.flyer.util.R;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

/**
 * 树
 *
 * @author flyer
 * @since 2024-05-09
 */
@RestController
@RequestMapping("/admin/tree")
public class TreeController {
    @Autowired
    private ITreeService iTreeService;

    /**
     * 新增果树
     *
     * @param addDTO
     * @return
     */
    @PostMapping("")
    public R addTree(@Valid @RequestBody TreeAddDTO addDTO) {
        return R.ok().result(iTreeService.addTree(addDTO));
    }

    /**
     * 修改树
     */
    @PutMapping("")
    public R updatePosterLib(@Valid @RequestBody TreeUpdateDTO updateDTO) {
        return R.ok().result(
                iTreeService.lambdaUpdate()
                        .set(Tree::getWkt, updateDTO.getWkt())
                        .set(Tree::getGardenId, updateDTO.getGardenId())
                        .set(Tree::getAreaId, updateDTO.getAreaId())
                        .eq(Tree::getId, updateDTO.getId())
                        .update());
    }

    /**
     * 根据gardenId获取详情
     *
     * @param gardenId
     * @return
     */
    @GetMapping("/{gardenId}")
    public R getTreeById(@PathVariable Integer gardenId) {
        return R.ok().result(iTreeService.getTreeById(gardenId));
    }

    /**
     * 删除树
     *
     * @param idList id集合
     * @return
     */
    @PostMapping("/delete")
    public R deleteTree(@RequestBody List<Integer> idList) {
        return R.ok().result(iTreeService.deleteByIdList(idList));
    }
}
