package com.flyer.util;

import com.flyer.enums.StatusCodeEnum;
import lombok.Data;

/**
 * R
 *
 * @author kelei
 * @since 2022/3/14/15:17
 */
@Data
public class R {
    private Integer code;
    private String message;
    private Object result;

    /**
     * 构造函数私有化
     */
    private R() {
    }

    /**
     * 返回成功结果
     *
     * @return
     */
    public static R ok() {
        R r = new R();
        r.setCode(StatusCodeEnum.SUCCESS.getCode());
        r.setMessage(StatusCodeEnum.SUCCESS.getMessage());
        return r;
    }

    public static R ok(StatusCodeEnum statusCodeEnum) {
        R r = new R();
        r.setCode(statusCodeEnum.getCode());
        r.setMessage(statusCodeEnum.getMessage());
        return r;
    }

    /**
     * 返回失败结果
     *
     * @return
     */
    public static R error() {
        R r = new R();
        r.setCode(StatusCodeEnum.ERROR.getCode());
        r.setMessage(StatusCodeEnum.ERROR.getMessage());
        return r;
    }

    /**
     * 返回指定失败结果
     *
     * @return
     */
    public static R error(StatusCodeEnum statusCodeEnum) {
        R r = new R();
        r.setCode(statusCodeEnum.getCode());
        r.setMessage(statusCodeEnum.getMessage());
        return r;
    }

    public <T> R result(T result) {
        this.setResult(result);
        return this;
    }

    /**
     * 设置特定的响应消息
     *
     * @param message
     * @return
     */
    public R message(String message) {
        this.setMessage(message);
        return this;
    }


    /**
     * 设置特定的响应码
     *
     * @param code
     * @return
     */
    public R code(Integer code) {
        this.setCode(code);
        return this;
    }
}
